package com.inspect.guideline.service;

import com.inspect.guideline.domain.PatrolGuidelineRule;

import java.util.List;

public interface IPatrolGuidelineRuleService {
    PatrolGuidelineRule selectPatrolGuidelineRuleByGuidelineRuleId(Long ruleId);

    List<PatrolGuidelineRule> selectPatrolGuidelineRuleList(PatrolGuidelineRule rule);

    int insertPatrolGuidelineRule(PatrolGuidelineRule rule);

    int updatePatrolGuidelineRule(PatrolGuidelineRule rule);

    int deletePatrolGuidelineRuleByGuidelineRuleIds(Long[] ruleIds);

    int deletePatrolGuidelineRuleByGuidelineRuleId(Long ruleId);
}
